==> RsPulseSeq-2.4.1.tar.gz: RsPulseSeq-2.4.1/RsPulseSeq/Implementations/Cpanel/Used/Path.py <==
from typing import List

from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from ....Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Path:
	"""Path commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("path", core, parent)

	def get_list_py(self) -> List[int]:
		"""SCPI: CPANel:USED:PATH:LIST \n
		Snippet: value: List[int] = driver.cpanel.used.path.get_list_py() \n
		Queries the available RF paths of the selected signal generators. \n
			:return: list_py: 'Path#1','Paht#2',...
		"""
		response = self._core.io.query_bin_or_ascii_int_list('CPANel:USED:PATH:LIST?')
		return response

	def get_select(self) -> str:
		"""SCPI: CPANel:USED:PATH:SELect \n
		Snippet: value: str = driver.cpanel.used.path.get_select() \n
		Selects the element to which the subsequent commands apply. \n
			:return: select: string Available element as queried with the corresponding ...:LIST command. For example, method RsPulseSeq.Assignment.Generator.Path.Antenna.listPy
		"""
		response = self._core.io.query_str('CPANel:USED:PATH:SELect?')
		return trim_str_response(response)

	def set_select(self, select: str) -> None:
		"""SCPI: CPANel:USED:PATH:SELect \n
		Snippet: driver.cpanel.used.path.set_select(select = '1') \n
		Selects the element to which the subsequent commands apply. \n
			:param select: string Available element as queried with the corresponding ...:LIST command. For example, method RsPulseSeq.Assignment.Generator.Path.Antenna.listPy
		"""
		param = Conversions.value_to_quoted_str(select)
		self._core.io.write(f'CPANel:USED:PATH:SELect {param}')

==> RsPulseSeq-2.7.1.tar.gz: RsPulseSeq-2.7.1/RsPulseSeq/Implementations/Cpanel/Used/Path.py <==
from typing import List

from ....Internal.Core import Core
from ....Internal.CommandsGroup import CommandsGroup
from ....Internal import Conversions
from ....Internal.Utilities import trim_str_response


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class PathCls:
	"""Path commands group definition. 2 total commands, 0 Subgroups, 2 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._cmd_group = CommandsGroup("path", core, parent)

	def get_list_py(self) -> List[str]:
		"""SCPI: CPANel:USED:PATH:LIST \n
		Snippet: value: List[str] = driver.cpanel.used.path.get_list_py() \n
		Queries the available RF paths of the selected signal generators. \n
			:return: list_py: 'Path#1','Paht#2',...
		"""
		response = self._core.io.query_str('CPANel:USED:PATH:LIST?')
		return Conversions.str_to_str_list(response)

	def get_select(self) -> str:
		"""SCPI: CPANel:USED:PATH:SELect \n
		Snippet: value: str = driver.cpanel.used.path.get_select() \n
		Selects the element to which the subsequent commands apply. \n
			:return: select: string Available element as queried with the corresponding ...:LIST command. For example, method RsPulseSeq.Assignment.Generator.Path.Antenna.listPy
		"""
		response = self._core.io.query_str('CPANel:USED:PATH:SELect?')
		return trim_str_response(response)

	def set_select(self, select: str) -> None:
		"""SCPI: CPANel:USED:PATH:SELect \n
		Snippet: driver.cpanel.used.path.set_select(select = 'abc') \n
		Selects the element to which the subsequent commands apply. \n
			:param select: string Available element as queried with the corresponding ...:LIST command. For example, method RsPulseSeq.Assignment.Generator.Path.Antenna.listPy
		"""
		param = Conversions.value_to_quoted_str(select)
		self._core.io.write(f'CPANel:USED:PATH:SELect {param}')
